things that are just implementation details of the crate, but might be nice to use (on a related topic to this crate)
do not expect (much) stability guarentees from this
Re-exports
pub use crate::event::async_fn_ptr;
Modules
Structs
- DynVar
- value must be Debug, just to make things easy
Traits
- AsAny
- This trait allows downcasting
dyn Traittodyn Any, which is neccesary when using thedowncastfunctions of Any with another trait - DynDebug
- Possibly
Clone - Allows for cloning types that may or may not be
Clone - Type
Named - Allows getting the name of the type contained in a
Box<dyn Any>