Module async_util

Module async_util 

Structs

OneOf
Allows polling two futures untill only one completes (or bolth, if they complete at the same time)

Enums

OneOfResult
The result of a OneOf future completeing, containing ether one or bolth of the completed futures