pub trait BusErrorUtil<T> {
    fn unwrap_or_fwd<'life0, 'async_trait>(
        self,
        bus: &'life0 BusInterface
    ) -> Pin<Box<dyn Future<Output = T> + Send + 'async_trait>>
    where
        'life0: 'async_trait,
        Self: 'async_trait
; }
Utility for handling bus errors inside of bus handlers

Required Methods

unwraps an Result, or forwards the error to BusInterface::fwd_bus_err.

see BusInterface::fwd_bus_err for more information

Implementations on Foreign Types

unwraps an Result, or forwards the error to BusInterface::fwd_bus_err.

see BusInterface::fwd_bus_err for more information

Implementors