Module extras

Module extras 

things that are just implementation details of the crate, but might be nice to use (on a related topic to this crate)

do not expect (much) stability guarentees from this

Re-exports

pub use crate::event::async_fn_ptr;

Modules

async_util

Structs

DynVar
value must be Debug, just to make things easy

Traits

AsAny
This trait allows downcasting dyn Trait to dyn Any, which is neccesary when using the downcast functions of Any with another trait
DynDebug
PossiblyClone
Allows for cloning types that may or may not be Clone
TypeNamed
Allows getting the name of the type contained in a Box<dyn Any>