Module async_util
dabus
0.5.1
Module async_
util
Module Items
Structs
Enums
In dabus::
extras
dabus
::
extras
Module
async_
util
Structs

OneOf
Allows polling two futures untill only
one
completes (or bolth, if they complete at the same time)
Enums

OneOf
Result
The result of a
OneOf
future completeing, containing ether one or bolth of the completed futures