Trait dabus::BusErrorUtil
source · [−]pub trait BusErrorUtil<T> {
fn unwrap_or_fwd<'life0, 'async_trait>(
self,
bus: &'life0 BusInterface
) -> Pin<Box<dyn Future<Output = T> + Send + 'async_trait>>
where
'life0: 'async_trait,
Self: 'async_trait;
}Expand description
Utility for handling bus errors inside of bus handlers
Required Methods
fn unwrap_or_fwd<'life0, 'async_trait>(
self,
bus: &'life0 BusInterface
) -> Pin<Box<dyn Future<Output = T> + Send + 'async_trait>> where
'life0: 'async_trait,
Self: 'async_trait,
fn unwrap_or_fwd<'life0, 'async_trait>(
self,
bus: &'life0 BusInterface
) -> Pin<Box<dyn Future<Output = T> + Send + 'async_trait>> where
'life0: 'async_trait,
Self: 'async_trait,
unwraps an Result, or forwards the error to BusInterface::fwd_bus_err.
see BusInterface::fwd_bus_err for more information
Implementations on Foreign Types
sourceimpl<T: Send> BusErrorUtil<T> for Result<T, CallTrace>
impl<T: Send> BusErrorUtil<T> for Result<T, CallTrace>
sourcefn unwrap_or_fwd<'life0, 'async_trait>(
self,
bus: &'life0 BusInterface
) -> Pin<Box<dyn Future<Output = T> + Send + 'async_trait>> where
'life0: 'async_trait,
Self: 'async_trait,
fn unwrap_or_fwd<'life0, 'async_trait>(
self,
bus: &'life0 BusInterface
) -> Pin<Box<dyn Future<Output = T> + Send + 'async_trait>> where
'life0: 'async_trait,
Self: 'async_trait,
unwraps an Result, or forwards the error to BusInterface::fwd_bus_err.
see BusInterface::fwd_bus_err for more information